==> blesta-3.1.3.zip: blesta/components/modules/vpsdotnet/language/en_us/vpsdotnet.php <==
<?php
// Basics
$lang['Vpsdotnet.name'] = "VPS.NET";
$lang['Vpsdotnet.module_row'] = "VPS.NET Master Server";
$lang['Vpsdotnet.module_row_plural'] = "Servers";
$lang['Vpsdotnet.module_group'] = "VPS.NET Master Group";

$lang['Vpsdotnet.order_options.first'] = "First non-full server";


// General
$lang['Vpsdotnet.please_wait'] = "Please wait...";


// Manage
$lang['Vpsdotnet.add_module_row'] = "Add Server";
$lang['Vpsdotnet.add_module_group'] = "Add Server Group";
$lang['Vpsdotnet.manage.module_rows_title'] = "VPS.NET Master Servers";
$lang['Vpsdotnet.manage.module_rows_heading.server_label'] = "Server Label";
$lang['Vpsdotnet.manage.module_rows_heading.email'] = "Email";
$lang['Vpsdotnet.manage.module_rows_heading.options'] = "Options";
$lang['Vpsdotnet.manage.module_rows.edit'] = "Edit";
$lang['Vpsdotnet.manage.module_rows.delete'] = "Delete";
$lang['Vpsdotnet.manage.module_rows.confirm_delete'] = "Are you sure you want to delete this server?";
$lang['Vpsdotnet.manage.module_rows_no_results'] = "There are no servers.";

$lang['Vpsdotnet.manage.module_groups_title'] = "VPS.NET Master Server Groups";
$lang['Vpsdotnet.manage.module_groups_heading.name'] = "Group Name";
$lang['Vpsdotnet.manage.module_groups_heading.servers'] = "Server Count";
$lang['Vpsdotnet.manage.module_groups_heading.options'] = "Options";
$lang['Vpsdotnet.manage.module_groups.edit'] = "Edit";
$lang['Vpsdotnet.manage.module_groups.delete'] = "Delete";
$lang['Vpsdotnet.manage.module_groups.confirm_delete'] = "Are you sure you want to delete this server group?";
$lang['Vpsdotnet.manage.module_groups_no_results'] = "There are no server groups.";


// Service info
$lang['Vpsdotnet.service_info.vpsdotnet_primary_ip_address'] = "Primary IP Address";
$lang['Vpsdotnet.service_info.vpsdotnet_password'] = "Password";


// Add module row
$lang['Vpsdotnet.add_row.box_title'] = "Add VPS.NET Server";
$lang['Vpsdotnet.add_row.basic_title'] = "Basic Settings";
$lang['Vpsdotnet.row_meta.server_name'] = "Server Label";
$lang['Vpsdotnet.row_meta.email'] = "Email";
$lang['Vpsdotnet.row_meta.key'] = "API Key";
$lang['Vpsdotnet.add_row.add_btn'] = "Add Server";


// Edit module row
$lang['Vpsdotnet.edit_row.box_title'] = "Edit VPS.NET Server";
$lang['Vpsdotnet.edit_row.basic_title'] = "Basic Settings";
$lang['Vpsdotnet.edit_row.add_btn'] = "Update Server";


// Package meta fields
$lang['Vpsdotnet.package_fields.number_of_nodes'] = "Number of Nodes";
$lang['Vpsdotnet.package_fields.client_set_cloud'] = "Let client set Cloud/Zone, Operating System, and Template";
$lang['Vpsdotnet.package_fields.admin_set_cloud'] = "Select a Cloud/Zone";
$lang['Vpsdotnet.package_fields.cloud'] = "Cloud/Zone";
$lang['Vpsdotnet.package_fields.client_set_template_group'] = "Let client set Operating System and Template";
$lang['Vpsdotnet.package_fields.admin_set_template_group'] = "Select Operating System";
$lang['Vpsdotnet.package_fields.template_group'] = "Operating System";
$lang['Vpsdotnet.package_fields.client_set_template'] = "Let client set Template";
$lang['Vpsdotnet.package_fields.admin_set_template'] = "Select Template";
$lang['Vpsdotnet.package_fields.template'] = "Template";


// Service fields
$lang['Vpsdotnet.service_field.vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.service_field.vpsdotnet_label'] = "VPS Label";
$lang['Vpsdotnet.service_field.vpsdotnet_cloud'] = "Cloud/Zone";
$lang['Vpsdotnet.service_field.vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.service_field.vpsdotnet_template'] = "Template";


// Tabs
$lang['Vpsdotnet.tab_actions'] = "Server Actions";
$lang['Vpsdotnet.tab_console'] = "Console";

$lang['Vpsdotnet.tab_client_actions'] = "Server Actions";
$lang['Vpsdotnet.tab_client_console'] = "Console";


// Server actions
$lang['Vpsdotnet.!actions.boot'] = "Boot";
$lang['Vpsdotnet.!actions.reboot'] = "Reboot";
$lang['Vpsdotnet.!actions.shutdown'] = "Shutdown";
$lang['Vpsdotnet.!actions.reinstall'] = "Reinstall";
$lang['Vpsdotnet.!actions.hostname'] = "Change Hostname";
$lang['Vpsdotnet.!actions.password'] = "Reset Password";


// Admin actions
$lang['Vpsdotnet.tab_actions.status_online'] = "Online";
$lang['Vpsdotnet.tab_actions.status_offline'] = "Offline";
$lang['Vpsdotnet.tab_actions.status_pending'] = "Pending";
$lang['Vpsdotnet.tab_actions.status_unknown'] = "Unknown";

$lang['Vpsdotnet.tab_actions.heading_actions'] = "Actions";
$lang['Vpsdotnet.tab_actions.server_status'] = "Server Status";

$lang['Vpsdotnet.tab_actions.heading_reinstall'] = "Reinstall";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_template'] = "Template";
$lang['Vpsdotnet.tab_actions.field_confirm'] = "I understand that by reinstalling, all data on the server will be permanently deleted, and the selected operating system and template will be installed.";
$lang['Vpsdotnet.tab_actions.field_reinstall_submit'] = "Reinstall";

$lang['Vpsdotnet.tab_actions.heading_hostname'] = "Change Hostname";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.tab_actions.field_hostname_submit'] = "Change Hostname";

$lang['Vpsdotnet.tab_actions.heading_password'] = "Reset Password";
$lang['Vpsdotnet.tab_actions.field_password_submit'] = "Reset Password";


// Client actions
$lang['Vpsdotnet.tab_client_actions.heading_server_status'] = "Server Status";

$lang['Vpsdotnet.tab_client_actions.status_online'] = "Online";
$lang['Vpsdotnet.tab_client_actions.status_offline'] = "Offline";
$lang['Vpsdotnet.tab_client_actions.status_pending'] = "Pending";
$lang['Vpsdotnet.tab_client_actions.status_unknown'] = "Unknown";

$lang['Vpsdotnet.tab_client_actions.heading_actions'] = "Actions";
$lang['Vpsdotnet.tab_client_actions.server_status'] = "Server Status";

$lang['Vpsdotnet.tab_client_actions.heading_reinstall'] = "Reinstall";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_template'] = "Template";
$lang['Vpsdotnet.tab_client_actions.field_confirm'] = "I understand that by reinstalling, all data on the server will be permanently deleted, and the selected operating system and template will be installed.";
$lang['Vpsdotnet.tab_client_actions.field_reinstall_submit'] = "Reinstall";

$lang['Vpsdotnet.tab_client_actions.heading_hostname'] = "Change Hostname";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.tab_client_actions.field_hostname_submit'] = "Change Hostname";

$lang['Vpsdotnet.tab_client_actions.heading_password'] = "Reset Password";
$lang['Vpsdotnet.tab_client_actions.field_password_submit'] = "Reset Password";


// Admin console
$lang['Vpsdotnet.tab_console.heading_console'] = "Console";
$lang['Vpsdotnet.tab_console.root_password'] = "Password:";


// Client console
$lang['Vpsdotnet.tab_client_console.heading_console'] = "Console";
$lang['Vpsdotnet.tab_client_console.root_password'] = "Password:";


// Errors
$lang['Vpsdotnet.!error.server_name.empty'] = "Please enter a label for this server.";
$lang['Vpsdotnet.!error.email.format'] = "Please enter a valid email address.";
$lang['Vpsdotnet.!error.key.empty'] = "Please enter your API key.";
$lang['Vpsdotnet.!error.key.valid_connection'] = "A connection to the server could not be established. Please check to ensure that the email address and API key are correct.";

$lang['Vpsdotnet.!error.nodes.add_failed'] = "Unable to add required nodes.";
$lang['Vpsdotnet.!error.vps.update_failed'] = "An error occurred and the Virtual Machine could not be updated.";
$lang['Vpsdotnet.!error.vps.action_failed'] = "An error occurred and the action could not be performed.";
$lang['Vpsdotnet.!error.vps.cancel_failed'] = "An error occurred and the service could not be cancelled.";
$lang['Vpsdotnet.!error.vps.reinstall_failed'] = "An error occurred and the template could not be reinstalled.";

$lang['Vpsdotnet.!error.vpsdotnet_template.valid'] = "Please select a valid template.";
$lang['Vpsdotnet.!error.confirm.valid'] = "You must acknowledge that you understand the reinstall action in order to perform the template reinstallation.";


// Package Errors
$lang['Vpsdotnet.!error.meta[number_of_nodes].format'] = "Please enter the number of nodes to be allocated.";
$lang['Vpsdotnet.!error.meta[set_cloud].format'] = "Please select whether to allow a client to set a cloud.";
$lang['Vpsdotnet.!error.meta[cloud].format'] = "Please select a valid cloud.";
$lang['Vpsdotnet.!error.meta[set_template_group].format'] = "Please select whether to allow a client to set the operating system.";
$lang['Vpsdotnet.!error.meta[template_group].format'] = "Please select a valid operating system.";
$lang['Vpsdotnet.!error.meta[set_template].format'] = "Please select whether to allow a client to set the template.";
$lang['Vpsdotnet.!error.meta[template].format'] = "Please select a valid template.";


// Service Errors
$lang['Vpsdotnet.!error.vpsdotnet_hostname.format'] = "The hostname appears to be invalid.";
$lang['Vpsdotnet.!error.vpsdotnet_label.empty'] = "Please enter a label.";
$lang['Vpsdotnet.!error.vpsdotnet_label.format'] = "The label may not contain special characters.";
$lang['Vpsdotnet.!error.vpsdotnet_cloud.format'] = "Please select a valid cloud.";
$lang['Vpsdotnet.!error.vpsdotnet_template_group.format'] = "Please select a valid operating system.";
$lang['Vpsdotnet.!error.vpsdotnet_template.format'] = "Please select a valid template.";
?>

==> blesta-3.2.0.zip: blesta/components/modules/vpsdotnet/language/en_us/vpsdotnet.php <==
<?php
// Basics
$lang['Vpsdotnet.name'] = "VPS.NET";
$lang['Vpsdotnet.module_row'] = "VPS.NET Master Server";
$lang['Vpsdotnet.module_row_plural'] = "Servers";
$lang['Vpsdotnet.module_group'] = "VPS.NET Master Group";

$lang['Vpsdotnet.order_options.first'] = "First non-full server";


// General
$lang['Vpsdotnet.please_wait'] = "Please wait...";


// Manage
$lang['Vpsdotnet.add_module_row'] = "Add Server";
$lang['Vpsdotnet.add_module_group'] = "Add Server Group";
$lang['Vpsdotnet.manage.module_rows_title'] = "VPS.NET Master Servers";
$lang['Vpsdotnet.manage.module_rows_heading.server_label'] = "Server Label";
$lang['Vpsdotnet.manage.module_rows_heading.email'] = "Email";
$lang['Vpsdotnet.manage.module_rows_heading.options'] = "Options";
$lang['Vpsdotnet.manage.module_rows.edit'] = "Edit";
$lang['Vpsdotnet.manage.module_rows.delete'] = "Delete";
$lang['Vpsdotnet.manage.module_rows.confirm_delete'] = "Are you sure you want to delete this server?";
$lang['Vpsdotnet.manage.module_rows_no_results'] = "There are no servers.";

$lang['Vpsdotnet.manage.module_groups_title'] = "VPS.NET Master Server Groups";
$lang['Vpsdotnet.manage.module_groups_heading.name'] = "Group Name";
$lang['Vpsdotnet.manage.module_groups_heading.servers'] = "Server Count";
$lang['Vpsdotnet.manage.module_groups_heading.options'] = "Options";
$lang['Vpsdotnet.manage.module_groups.edit'] = "Edit";
$lang['Vpsdotnet.manage.module_groups.delete'] = "Delete";
$lang['Vpsdotnet.manage.module_groups.confirm_delete'] = "Are you sure you want to delete this server group?";
$lang['Vpsdotnet.manage.module_groups_no_results'] = "There are no server groups.";


// Service info
$lang['Vpsdotnet.service_info.vpsdotnet_primary_ip_address'] = "Primary IP Address";
$lang['Vpsdotnet.service_info.vpsdotnet_password'] = "Password";


// Add module row
$lang['Vpsdotnet.add_row.box_title'] = "Add VPS.NET Server";
$lang['Vpsdotnet.add_row.basic_title'] = "Basic Settings";
$lang['Vpsdotnet.row_meta.server_name'] = "Server Label";
$lang['Vpsdotnet.row_meta.email'] = "Email";
$lang['Vpsdotnet.row_meta.key'] = "API Key";
$lang['Vpsdotnet.add_row.add_btn'] = "Add Server";


// Edit module row
$lang['Vpsdotnet.edit_row.box_title'] = "Edit VPS.NET Server";
$lang['Vpsdotnet.edit_row.basic_title'] = "Basic Settings";
$lang['Vpsdotnet.edit_row.add_btn'] = "Update Server";


// Package meta fields
$lang['Vpsdotnet.package_fields.number_of_nodes'] = "Number of Nodes";
$lang['Vpsdotnet.package_fields.client_set_cloud'] = "Let client set Cloud/Zone, Operating System, and Template";
$lang['Vpsdotnet.package_fields.admin_set_cloud'] = "Select a Cloud/Zone";
$lang['Vpsdotnet.package_fields.cloud'] = "Cloud/Zone";
$lang['Vpsdotnet.package_fields.client_set_template_group'] = "Let client set Operating System and Template";
$lang['Vpsdotnet.package_fields.admin_set_template_group'] = "Select Operating System";
$lang['Vpsdotnet.package_fields.template_group'] = "Operating System";
$lang['Vpsdotnet.package_fields.client_set_template'] = "Let client set Template";
$lang['Vpsdotnet.package_fields.admin_set_template'] = "Select Template";
$lang['Vpsdotnet.package_fields.template'] = "Template";


// Service fields
$lang['Vpsdotnet.service_field.vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.service_field.vpsdotnet_label'] = "VPS Label";
$lang['Vpsdotnet.service_field.vpsdotnet_cloud'] = "Cloud/Zone";
$lang['Vpsdotnet.service_field.vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.service_field.vpsdotnet_template'] = "Template";


// Tabs
$lang['Vpsdotnet.tab_actions'] = "Server Actions";
$lang['Vpsdotnet.tab_console'] = "Console";

$lang['Vpsdotnet.tab_client_actions'] = "Server Actions";
$lang['Vpsdotnet.tab_client_console'] = "Console";


// Server actions
$lang['Vpsdotnet.!actions.boot'] = "Boot";
$lang['Vpsdotnet.!actions.reboot'] = "Reboot";
$lang['Vpsdotnet.!actions.shutdown'] = "Shutdown";
$lang['Vpsdotnet.!actions.reinstall'] = "Reinstall";
$lang['Vpsdotnet.!actions.hostname'] = "Change Hostname";
$lang['Vpsdotnet.!actions.password'] = "Reset Password";


// Admin actions
$lang['Vpsdotnet.tab_actions.status_online'] = "Online";
$lang['Vpsdotnet.tab_actions.status_offline'] = "Offline";
$lang['Vpsdotnet.tab_actions.status_pending'] = "Pending";
$lang['Vpsdotnet.tab_actions.status_unknown'] = "Unknown";

$lang['Vpsdotnet.tab_actions.heading_actions'] = "Actions";
$lang['Vpsdotnet.tab_actions.server_status'] = "Server Status";

$lang['Vpsdotnet.tab_actions.heading_reinstall'] = "Reinstall";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_template'] = "Template";
$lang['Vpsdotnet.tab_actions.field_confirm'] = "I understand that by reinstalling, all data on the server will be permanently deleted, and the selected operating system and template will be installed.";
$lang['Vpsdotnet.tab_actions.field_reinstall_submit'] = "Reinstall";

$lang['Vpsdotnet.tab_actions.heading_hostname'] = "Change Hostname";
$lang['Vpsdotnet.tab_actions.field_vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.tab_actions.field_hostname_submit'] = "Change Hostname";

$lang['Vpsdotnet.tab_actions.heading_password'] = "Reset Password";
$lang['Vpsdotnet.tab_actions.field_password_submit'] = "Reset Password";


// Client actions
$lang['Vpsdotnet.tab_client_actions.heading_server_status'] = "Server Status";

$lang['Vpsdotnet.tab_client_actions.status_online'] = "Online";
$lang['Vpsdotnet.tab_client_actions.status_offline'] = "Offline";
$lang['Vpsdotnet.tab_client_actions.status_pending'] = "Pending";
$lang['Vpsdotnet.tab_client_actions.status_unknown'] = "Unknown";

$lang['Vpsdotnet.tab_client_actions.heading_actions'] = "Server Actions";

$lang['Vpsdotnet.tab_client_actions.heading_reinstall'] = "Reinstall";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_template_group'] = "Operating System";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_template'] = "Template";
$lang['Vpsdotnet.tab_client_actions.field_confirm'] = "I understand that by reinstalling, all data on the server will be permanently deleted, and the selected operating system and template will be installed.";
$lang['Vpsdotnet.tab_client_actions.field_reinstall_submit'] = "Reinstall";

$lang['Vpsdotnet.tab_client_actions.heading_hostname'] = "Change Hostname";
$lang['Vpsdotnet.tab_client_actions.field_vpsdotnet_hostname'] = "Hostname";
$lang['Vpsdotnet.tab_client_actions.field_hostname_submit'] = "Change Hostname";

$lang['Vpsdotnet.tab_client_actions.heading_password'] = "Reset Password";
$lang['Vpsdotnet.tab_client_actions.field_password_submit'] = "Reset Password";


// Admin console
$lang['Vpsdotnet.tab_console.heading_console'] = "Console";
$lang['Vpsdotnet.tab_console.root_password'] = "Password:";


// Client console
$lang['Vpsdotnet.tab_client_console.heading_console'] = "Console";
$lang['Vpsdotnet.tab_client_console.root_password'] = "Password";


// Errors
$lang['Vpsdotnet.!error.server_name.empty'] = "Please enter a label for this server.";
$lang['Vpsdotnet.!error.email.format'] = "Please enter a valid email address.";
$lang['Vpsdotnet.!error.key.empty'] = "Please enter your API key.";
$lang['Vpsdotnet.!error.key.valid_connection'] = "A connection to the server could not be established. Please check to ensure that the email address and API key are correct.";

$lang['Vpsdotnet.!error.nodes.add_failed'] = "Unable to add required nodes.";
$lang['Vpsdotnet.!error.vps.update_failed'] = "An error occurred and the Virtual Machine could not be updated.";
$lang['Vpsdotnet.!error.vps.action_failed'] = "An error occurred and the action could not be performed.";
$lang['Vpsdotnet.!error.vps.cancel_failed'] = "An error occurred and the service could not be cancelled.";
$lang['Vpsdotnet.!error.vps.reinstall_failed'] = "An error occurred and the template could not be reinstalled.";

$lang['Vpsdotnet.!error.vpsdotnet_template.valid'] = "Please select a valid template.";
$lang['Vpsdotnet.!error.confirm.valid'] = "You must acknowledge that you understand the reinstall action in order to perform the template reinstallation.";


// Package Errors
$lang['Vpsdotnet.!error.meta[number_of_nodes].format'] = "Please enter the number of nodes to be allocated.";
$lang['Vpsdotnet.!error.meta[set_cloud].format'] = "Please select whether to allow a client to set a cloud.";
$lang['Vpsdotnet.!error.meta[cloud].format'] = "Please select a valid cloud.";
$lang['Vpsdotnet.!error.meta[set_template_group].format'] = "Please select whether to allow a client to set the operating system.";
$lang['Vpsdotnet.!error.meta[template_group].format'] = "Please select a valid operating system.";
$lang['Vpsdotnet.!error.meta[set_template].format'] = "Please select whether to allow a client to set the template.";
$lang['Vpsdotnet.!error.meta[template].format'] = "Please select a valid template.";


// Service Errors
$lang['Vpsdotnet.!error.vpsdotnet_hostname.format'] = "The hostname appears to be invalid.";
$lang['Vpsdotnet.!error.vpsdotnet_label.empty'] = "Please enter a label.";
$lang['Vpsdotnet.!error.vpsdotnet_label.format'] = "The label may not contain special characters.";
$lang['Vpsdotnet.!error.vpsdotnet_cloud.format'] = "Please select a valid cloud.";
$lang['Vpsdotnet.!error.vpsdotnet_template_group.format'] = "Please select a valid operating system.";
$lang['Vpsdotnet.!error.vpsdotnet_template.format'] = "Please select a valid template.";
?>
